==> zio-aws-codegurureviewer_2.13-5.17.115.1-sources.jar: zio/aws/codegurureviewer/model/AssociateRepositoryResponse.scala <==
package zio.aws.codegurureviewer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.codegurureviewer.model.primitives.{TagValue, TagKey}
import scala.jdk.CollectionConverters._
final case class AssociateRepositoryResponse(
    repositoryAssociation: Option[
      zio.aws.codegurureviewer.model.RepositoryAssociation
    ] = None,
    tags: Option[Map[TagKey, TagValue]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codegurureviewer.model.AssociateRepositoryResponse = {
    import AssociateRepositoryResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codegurureviewer.model.AssociateRepositoryResponse
      .builder()
      .optionallyWith(
        repositoryAssociation.map(value => value.buildAwsValue())
      )(_.repositoryAssociation)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.codegurureviewer.model.AssociateRepositoryResponse.ReadOnly =
    zio.aws.codegurureviewer.model.AssociateRepositoryResponse
      .wrap(buildAwsValue())
}
object AssociateRepositoryResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codegurureviewer.model.AssociateRepositoryResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codegurureviewer.model.AssociateRepositoryResponse =
      zio.aws.codegurureviewer.model.AssociateRepositoryResponse(
        repositoryAssociation.map(value => value.asEditable),
        tags.map(value => value)
      )
    def repositoryAssociation
        : Option[zio.aws.codegurureviewer.model.RepositoryAssociation.ReadOnly]
    def tags: Option[Map[TagKey, TagValue]]
    def getRepositoryAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.codegurureviewer.model.RepositoryAssociation.ReadOnly
    ] =
      AwsError.unwrapOptionField("repositoryAssociation", repositoryAssociation)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codegurureviewer.model.AssociateRepositoryResponse
  ) extends zio.aws.codegurureviewer.model.AssociateRepositoryResponse.ReadOnly {
    override val repositoryAssociation: Option[
      zio.aws.codegurureviewer.model.RepositoryAssociation.ReadOnly
    ] = scala
      .Option(impl.repositoryAssociation())
      .map(value =>
        zio.aws.codegurureviewer.model.RepositoryAssociation.wrap(value)
      )
    override val tags: Option[Map[TagKey, TagValue]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.codegurureviewer.model.primitives.TagKey(
              key
            ) -> zio.aws.codegurureviewer.model.primitives.TagValue(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codegurureviewer.model.AssociateRepositoryResponse
  ): zio.aws.codegurureviewer.model.AssociateRepositoryResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codegurureviewer_2.13-5.17.186.1-sources.jar: zio/aws/codegurureviewer/model/AssociateRepositoryResponse.scala <==
package zio.aws.codegurureviewer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codegurureviewer.model.primitives.{TagValue, TagKey}
import scala.jdk.CollectionConverters._
final case class AssociateRepositoryResponse(
    repositoryAssociation: Optional[
      zio.aws.codegurureviewer.model.RepositoryAssociation
    ] = Optional.Absent,
    tags: Optional[Map[TagKey, TagValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codegurureviewer.model.AssociateRepositoryResponse = {
    import AssociateRepositoryResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codegurureviewer.model.AssociateRepositoryResponse
      .builder()
      .optionallyWith(
        repositoryAssociation.map(value => value.buildAwsValue())
      )(_.repositoryAssociation)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.codegurureviewer.model.AssociateRepositoryResponse.ReadOnly =
    zio.aws.codegurureviewer.model.AssociateRepositoryResponse
      .wrap(buildAwsValue())
}
object AssociateRepositoryResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codegurureviewer.model.AssociateRepositoryResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codegurureviewer.model.AssociateRepositoryResponse =
      zio.aws.codegurureviewer.model.AssociateRepositoryResponse(
        repositoryAssociation.map(value => value.asEditable),
        tags.map(value => value)
      )
    def repositoryAssociation: Optional[
      zio.aws.codegurureviewer.model.RepositoryAssociation.ReadOnly
    ]
    def tags: Optional[Map[TagKey, TagValue]]
    def getRepositoryAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.codegurureviewer.model.RepositoryAssociation.ReadOnly
    ] =
      AwsError.unwrapOptionField("repositoryAssociation", repositoryAssociation)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codegurureviewer.model.AssociateRepositoryResponse
  ) extends zio.aws.codegurureviewer.model.AssociateRepositoryResponse.ReadOnly {
    override val repositoryAssociation: Optional[
      zio.aws.codegurureviewer.model.RepositoryAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.repositoryAssociation())
      .map(value =>
        zio.aws.codegurureviewer.model.RepositoryAssociation.wrap(value)
      )
    override val tags: Optional[Map[TagKey, TagValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.codegurureviewer.model.primitives.TagKey(
              key
            ) -> zio.aws.codegurureviewer.model.primitives.TagValue(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codegurureviewer.model.AssociateRepositoryResponse
  ): zio.aws.codegurureviewer.model.AssociateRepositoryResponse.ReadOnly =
    new Wrapper(impl)
}
